@@ -1,4 +1,3 @@
-# pylint: disable=C0103
 """
 V/Hz control for induction motor drives.
 
@@ -22,11 +21,9 @@ References
 
 """
 # %%
-from __future__ import annotations
-from collections.abc import Callable
+from typing import Callable
 from dataclasses import dataclass, field
 import numpy as np
-
 from motulator.control.common import Ctrl, PWM, RateLimiter
 from motulator.helpers import abc2complex, Bunch
 
