@@ -1,12 +1,10 @@
-# pylint: disable=invalid-name
 """
 Flux-vector control for synchronous motor drives.
 
-This implements a simplified version of stator-flux-vector control [1]_. The
-rotor coordinates are used in this implementation [2]_. One control variable is
-the stator-flux magnitude and another is the electromagnetic torque. The latter
-choice differs from [1]_ and [2]_, where the torque-producing current component
-is used. Furthermore, here proportional control is used for simplicity. The
+This implements a version of stator-flux-vector control [1]_. Rotor coordinates 
+as well as decoupling between the stator flux and torque channels are used [2]_. 
+Here, the stator flux magnitude and the electromagnetic torque are selected as
+controllable variables. Proportional controllers are used for simplicity. The 
 magnetic saturation is not considered in this implementation.
 
 References
@@ -20,15 +18,13 @@ References
    2019, https://doi.org/10.1109/TIA.2019.2927316
 
 """
-from __future__ import annotations
-from collections.abc import Callable
+from typing import Callable
 from dataclasses import dataclass, field
 import numpy as np
-
 from motulator.helpers import abc2complex, Bunch
 from motulator.control.common import Ctrl, SpeedCtrl, PWM
-from motulator.control.sm_torque import TorqueCharacteristics
 from motulator.control.sm_vector import SensorlessObserver
+from motulator.control.sm_obs_vhz import FluxTorqueRef
 
 
 # %%
@@ -44,17 +40,14 @@ class SynchronousMotorFluxVectorCtrlPars:
     sensorless: bool = True
     # Sampling period
     T_s: float = 250e-6
-    # Nominal flux
-    psi_s_nom: float = np.sqrt(2/3)*370/(2*np.pi*75)
-    # Maximum flux
-    psi_s_max: float = np.sqrt(2/3)*370/(2*np.pi*75)
-    # Minimum flux
-    psi_s_min: float = .5*np.sqrt(2/3)*370/(2*np.pi*75)
+    # Flux reference limits
+    psi_s_min: float = None
+    psi_s_max: float = None
     # Voltage marginal
     k_u: float = .9
     # Bandwidths
-    alpha_psi: float = 2*np.pi*100
-    alpha_tau_max: float = 2*np.pi*400
+    alpha_psi: float = 2*np.pi*150
+    alpha_tau: float = 2*np.pi*50
     alpha_s: float = 2*np.pi*4
     # Maximum values
     tau_M_max: float = 1.5*14
@@ -64,10 +57,10 @@ class SynchronousMotorFluxVectorCtrlPars:
     L_d: float = .036
     L_q: float = .051
     psi_f: float = .545
-    p: int = 3
+    n_p: int = 3
     J: float = .015
     # Sensorless observer (used only in the sensorless mode)
-    w_o: float = 2*np.pi*40
+    w_o: float = 2*np.pi*100
     zeta_inf: float = .2
     # Sensored observer (used only in the sensored mode)
     g: float = 2*np.pi*15
@@ -93,10 +86,7 @@ class SynchronousMotorFluxVectorCtrl(Ctrl):
         super().__init__()
         self.T_s = pars.T_s
         self.w_m_ref = pars.w_m_ref
-        self.p = pars.p
-        self.L_d, self.L_q, self.psi_f = pars.L_d, pars.L_q, pars.psi_f
         self.sensorless = pars.sensorless
-        self.flux_torque_ctrl = FluxTorqueCtrl(pars)
         self.speed_ctrl = SpeedCtrl(pars)
         self.pwm = PWM(pars)
         if pars.sensorless:
@@ -104,6 +94,14 @@ class SynchronousMotorFluxVectorCtrl(Ctrl):
         else:
             self.observer = Observer(pars)
         self.flux_torque_ref = FluxTorqueRef(pars)
+        # Bandwidths
+        self.alpha_psi = pars.alpha_psi
+        self.alpha_tau = pars.alpha_tau
+        # Motor parameter estimates
+        self.R_s = pars.R_s
+        self.L_d = pars.L_d
+        self.L_q = pars.L_q
+        self.n_p = pars.n_p
 
     def __call__(self, mdl):
         """
@@ -136,22 +134,40 @@ class SynchronousMotorFluxVectorCtrl(Ctrl):
             w_m, theta_m = self.observer.w_m, self.observer.theta_m
         else:
             # Measure the rotor speed
-            w_m = self.p*mdl.mech.meas_speed()
+            w_m = self.n_p*mdl.mech.meas_speed()
             # Limit the electrical rotor position into [-pi, pi)
             theta_m = np.mod(
-                self.p*mdl.mech.meas_position() + np.pi, 2*np.pi) - np.pi
+                self.n_p*mdl.mech.meas_position() + np.pi, 2*np.pi) - np.pi
 
         # Current vector in estimated rotor coordinates
         i_s = np.exp(-1j*theta_m)*abc2complex(i_s_abc)
 
         # Flux and torque estimates
         psi_s = self.observer.psi_s
+        tau_M = 1.5*self.n_p*np.imag(i_s*np.conj(psi_s))
 
         # Outputs
-        tau_M_ref = self.speed_ctrl.output(w_m_ref/self.p, w_m/self.p)
+        tau_M_ref = self.speed_ctrl.output(w_m_ref/self.n_p, w_m/self.n_p)
         psi_s_ref, tau_M_ref_lim = self.flux_torque_ref(tau_M_ref, w_m, u_dc)
-        u_s_ref = self.flux_torque_ctrl(
-            psi_s_ref, tau_M_ref_lim, psi_s, i_s, w_m, u_dc)
+
+        # Auxiliary current
+        i_a = psi_s.real/self.L_q + 1j*psi_s.imag/self.L_d - i_s
+
+        # Torque-production factor (c_tau = 0 corresponds to the MTPV condition)
+        c_tau = np.real(i_a*np.conj(psi_s))
+
+        # References for the flux and torque controllers
+        v_psi = self.alpha_psi*(psi_s_ref - np.abs(psi_s))
+        v_tau = self.alpha_tau*(tau_M_ref_lim - tau_M)
+        if c_tau > 0:
+            v = (np.abs(psi_s)*i_a*v_psi + 1j*psi_s*v_tau)/c_tau
+        else:
+            v = v_psi
+
+        # Stator voltage reference
+        u_s_ref = self.R_s*i_s + 1j*w_m*psi_s + v
+
+        # PWM output
         d_abc_ref, u_s_ref_lim = self.pwm.output(u_s_ref, u_dc, theta_m, w_m)
 
         # Data logging
@@ -178,143 +194,6 @@ class SynchronousMotorFluxVectorCtrl(Ctrl):
         return self.T_s, d_abc_ref
 
 
-# %%
-class FluxTorqueCtrl:
-    """
-    Stator flux and torque controller.
-
-    Parameters
-    ----------
-    pars : SynchronousMotoroFluxVectorCtrlPars
-        Control parameters.
-
-    """
-
-    # pylint: disable=too-few-public-methods
-    def __init__(self, pars):
-        self.T_s = pars.T_s
-        self.R_s = pars.R_s
-        self.p = pars.p
-        self.alpha_psi = pars.alpha_psi
-        G = (pars.L_d - pars.L_q)/(pars.L_d*pars.L_q)
-        c_delta_max = 1.5*pars.p*(
-            pars.psi_f*pars.psi_s_nom/pars.L_d + G*pars.psi_s_nom**2)
-        self.k_tau = pars.alpha_tau_max/c_delta_max
-
-    def __call__(self, psi_s_ref, tau_M_ref, psi_s, i_s, w_m, u_dc):
-        """
-        Compute the unlimited voltage reference.
-
-        Parameters
-        ----------
-        psi_s_ref : float
-            Stator flux reference (magnitude).
-        tau_M_ref : float
-            Torque reference.
-        psi_s : complex
-            Stator flux estimate.
-        i_s : complex
-            Stator current.
-        w_m : float
-            Rotor speed (in electrical rad/s).
-        u_dc : float
-            DC-bus voltage.
-
-        Returns
-        -------
-        u_s_ref : complex
-            Unlimited voltage reference.
-
-        """
-        # Torque estimate
-        tau_M = 1.5*self.p*np.imag(i_s*np.conj(psi_s))
-
-        # Stator frequency
-        w_s = w_m + self.k_tau*(tau_M_ref - tau_M)
-
-        # Voltage reference
-        e_psi = psi_s_ref - np.abs(psi_s)
-        delta = np.angle(psi_s)
-        u_s_ref = (
-            self.R_s*i_s + 1j*w_s*psi_s +
-            self.alpha_psi*e_psi*np.exp(1j*delta))
-
-        return u_s_ref
-
-
-# %%
-class FluxTorqueRef:
-    """
-    Flux and torque references.
-
-    Parameters
-    ----------
-    pars : SynchronousMotoroFluxVectorCtrlPars
-        Control parameters.
-
-    """
-
-    # pylint: disable=too-few-public-methods
-    def __init__(self, pars):
-        self.psi_s_min = pars.psi_s_min
-        try:
-            self.psi_s_max = pars.psi_s_max
-        except AttributeError:
-            self.psi_s_max = np.inf
-        self.k_u = pars.k_u
-        # Merged MTPV and current limits
-        tq = TorqueCharacteristics(pars)
-        lims = tq.mtpv_and_current_limits(i_s_max=pars.i_s_max)
-        self.tau_M_lim = lims.tau_M_vs_abs_psi_s
-        # MTPA locus
-        mtpa = tq.mtpa_locus(i_s_max=pars.i_s_max)
-        self.psi_s_mtpa = mtpa.abs_psi_s_vs_tau_M
-
-    def __call__(self, tau_M_ref, w_m, u_dc):
-        """
-        Calculate the stator flux reference and limit the torque reference.
-
-        Parameters
-        ----------
-        tau_M_ref : float
-            Unlimited torque reference.
-        w_m : float
-            Rotor speed (in electrical rad/s).
-        u_dc : float
-            DC-bus voltage.
-
-        Returns
-        -------
-        psi_s_ref : float
-            Stator flux reference.
-        tau_M_ref_lim : float
-            Limited torque reference.
-
-        """
-        # Get the MTPA flux
-        psi_s_mtpa = self.psi_s_mtpa(np.abs(tau_M_ref))
-        # Limit the MTPA flux for sensorless drives
-        psi_s_mtpa = np.max([psi_s_mtpa, self.psi_s_min])
-        # Limit the MTPA flux to avoid magnetic saturation
-        psi_s_mtpa = np.min([psi_s_mtpa, self.psi_s_max])
-
-        # Field weakening
-        if np.abs(w_m) > 0:
-            psi_s_max = self.k_u*u_dc/np.sqrt(3)/np.abs(w_m)
-        else:
-            psi_s_max = np.inf
-
-        # Flux reference
-        psi_s_ref = np.min([psi_s_max, psi_s_mtpa])
-
-        # Limit the torque reference according to the MTPV and current limits
-        tau_M_lim = self.tau_M_lim(psi_s_ref)
-        tau_M_ref_lim = np.min([tau_M_lim, np.abs(tau_M_ref)
-                                ])*np.sign(tau_M_ref)
-
-        return psi_s_ref, tau_M_ref_lim
-
-
 # %%
 class Observer:
     """
@@ -327,7 +206,6 @@ class Observer:
 
     """
 
-    # pylint: disable=too-few-public-methods
     def __init__(self, pars):
         self.T_s = pars.T_s
         self.R_s = pars.R_s
